#
# spec file for package ghc-OpenGL
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name OpenGL
Name:           ghc-%{pkg_name}
Version:        3.0.1.0
Release:        4.13
Summary:        A binding for the OpenGL graphics system
License:        BSD-3-Clause
Group:          System/Libraries
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
# Begin cabal-rpm deps:
BuildRequires:  ghc-GLURaw-devel
BuildRequires:  ghc-ObjectName-devel
BuildRequires:  ghc-OpenGLRaw-devel
BuildRequires:  ghc-StateVar-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# End cabal-rpm deps

%description
A Haskell binding for the OpenGL graphics system (GL, version 4.5) and its
accompanying utility library (GLU, version 1.3).

OpenGL is the industry's most widely used and supported 2D and 3D graphics
application programming interface (API), incorporating a broad set of
rendering, texture mapping, special effects, and other powerful visualization
functions. For more information about OpenGL and its various extensions, please
see <http://www.opengl.org/> and <http://www.opengl.org/registry/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 3.0.1.0 revision 0 with cabal2obs.
* Thu May 12 2016 mimi.vx@gmail.com
- update to 3.0.1.0
  * Added Uniform instances for GLmatrix, Vertex1, Vector1, Vector2, Vector3,
    and Vector4.
  * Unbreak Uniform instances for GLint, GLuint and Gldouble.
  * Relaxed upper version bound for OpenGLRaw.
* Tue Apr 12 2016 mimi.vx@gmail.com
- update to 3.0.0.2
  * Removed redundant constraints.
* Mon Jan 11 2016 mimi.vx@gmail.com
- update to 3.0.0.1
  * Relaxed upper version bound for OpenGLRaw.
* Mon Jan  4 2016 mimi.vx@gmail.com
- update to 3.0.0.0
  * Depend on new OpenGLRaw and GLURaw packages
* Thu Dec 24 2015 mimi.vx@gmail.com
- update to 2.13.2.1
  * Relaxed upper version bound for transformers.
* Mon Dec 21 2015 mimi.vx@gmail.com
- update to 2.13.2.0
  * Implement Uniform instances for GLint, GLuint, GLfloat, and GLdouble.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 2.13.1.1
  * Aftermath for the glClearNamedFramebufferfi chaos in the OpenGL registry, see
    the corresponding issue on Khronos.
  * Added extensionSupported.
  * Relaxed upper version bound for OpenGLRaw.
  * Added missing drawing commands using vertex arrays and some related types.
  * Added missing whole framebuffer operations.
  * Added getters for stencilMaskSeparate, stencilFuncSeparate, and stencilOpSeparate,
    making them full-blown StateVars.
  * Added patchDefaultInnerLevel and patchDefaultOuterLevel to control the default
    tessellation levels.
  * Added ContextLost constructor to ErrorCategory type.
  * Added SeparateAttribs and deprecated SeperateAttribs, fixing a spelling mistake.
* Sun Nov 15 2015 peter.trommler@ohm-hochschule.de
- update to 2.13.1.0
  * extended API
  * version bounds for OpenGLRaw
  * new file CHANGELOG.md
* Tue May  5 2015 mimi.vx@gmail.com
- update to 2.12.0.1
* Thu Apr 16 2015 mimi.vx@gmail.com
- update to 2.12.0.0
- regenerated spec with cabal-rpm
  * no upstream changelog
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- update to 2.9.2.0 for Haskell Platform 2014.2.0.0
  * no changelog
* Fri Aug 22 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 2.8.0.0 from upstream
  * no upstream changelog
  * refactored : new packages OpenGLRaw and GLURaw
  * documentation issues fixed
- part of Haskell Platform 2013.2
* Tue Jan  1 2013 peter.trommler@ohm-hochschule.de
- deleted comment in changelog section
- fixed minor typo in last change log entry
* Sun Dec 30 2012 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Fri Sep 28 2012 peter.trommler@ohm-hochschule.de
- dropped rpmlintrc
* Fri Sep 28 2012 peter.trommler@ohm-hochschule.de
- removed Mesa-devel from Factory build
* Fri Sep 28 2012 peter.trommler@ohm-hochschule.de
- fixed build requires for libGLU split off Mesa in Factory
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- fixed build requires
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- update to 2.2.3.1 from upstream (no changelog)
- required by Haskell Platform 2012.2.0.0
* Thu Feb 23 2012 peter.trommler@ohm-hochschule.de
- Added BuildRoot for sle11-sp1
* Sun Jan  1 2012 peter.trommler@ohm-hochschule.de
- Adjusted version for platform 2011.4
* Sat Dec 31 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
